### dereplicate reads into uniq sequences
rule dereplicate_samples:
    input:
        '../03_demultiplex/02_raw/{demultiplexs}.fasta'
    output:
        '01_dereplicated/{demultiplexs}.uniq.fasta'
    singularity:
        config["singularity"]["obitools"]
    log:
        '../99_log/04_filter_samples/01_dereplicated/{demultiplexs}.log'
    params:
        dmulti= lambda wildcards: dfMultiChecked[dfMultiChecked.demultiplex == wildcards.demultiplexs].to_dict('records')[0],        
    shell:
        '''mkdir -p 01_dereplicated/{params.dmulti[projmarkrun]}; obiuniq -m sample {input} > {output} 2> {log}'''

### only sequence more than 20bp with no ambiguity IUAPC with total coverage greater than 10 reads
rule goodlength_samples:
    input:
        '01_dereplicated/{demultiplexs}.uniq.fasta'
    output:
        '02_goodlength/{demultiplexs}.l.u.fasta'
    singularity:
        config["singularity"]["obitools"]
    log:
        '../99_log/04_filter_samples/02_goodlength/{demultiplexs}.log'
    params:
        count=config["good_length_samples"]["count"],
        seq_length=config["good_length_samples"]["seq_length"]        
    shell:
        '''obigrep  -p 'count>{params.count}' -s '^[ACGT]+$' -p 'seq_length>{params.seq_length}' {input} > {output} 2> {log}'''

### Clean the sequences for PCR/sequencing errors (sequence variants)
rule clean_pcrerr_samples:
    input:
        '02_goodlength/{demultiplexs}.l.u.fasta'
    output:
        '03_clean_pcrerr/{demultiplexs}.r.l.u.fasta'
    singularity:
        config["singularity"]["obitools"]
    log:
        '../99_log/04_filter_samples/03_clean_pcrerr/{demultiplexs}.log'
    params:
         r=config["clean_pcrerr_samples"]["r"]         
    shell:
        '''if [[ -s {input} ]]; then obiclean -r {params.r} {input} > {output} 2> {log} ; else touch {output} 2> {log} ; fi'''

### Remove sequence which are classified as 'internal' by obiclean
rule rm_internal_samples:
    input:
        '03_clean_pcrerr/{demultiplexs}.r.l.u.fasta'
    output:
        '04_filtered/{demultiplexs}.c.r.l.u.fasta'
    params:
        dmulti= lambda wildcards: dfMultiChecked[dfMultiChecked.demultiplex == wildcards.demultiplexs].to_dict('records')[0],
    singularity:
        config["singularity"]["obitools"]
    log:
        '../99_log/04_filter_samples/04_filtered/{demultiplexs}.log'
    shell:
        '''if [[ -s {input} ]]; then mkdir -p 04_filtered/{params.dmulti[projmarkrun]}; obigrep -p "obiclean_internalcount == 0" {input} > {output} 2> {log} ; else touch {output} 2> {log} ; fi'''
