# edna--smk_rapidrun_obitools
snakemake obitools workflow to process rapidrun eDNA data



# Prerequisites


* python3

* snakemake

* singularity

python3 dependencies

```
pip3 install pandas
pip3 install biopython
```

python3 dependencies to run `snakemake`:

```
pip3 install datrie
pip3 install ConfigArgParse
pip3 install appdirs
pip3 install gitdb2
```

# Configuration / input files

You have to set 2 files:

* [01_infos/all_samples.tsv](01_infos/all_samples.tsv)
* [01_infos/config.yaml](01_infos/config_test.yaml)


# The Workflow

## 1. Set rapidrun 

Indicate the path of [01_infos/all_samples.tsv](01_infos/all_samples.tsv) file in the `fichiers` `rapidrun` field in [01_infos/config.yaml](01_infos/config_test.yaml)


```
CONFIGFILE=01_infos/config_test.yaml
snakemake --configfile $CONFIGFILE -s readwrite_rapidrun_demultiplexing.py
```
This command will read [01_infos/all_samples.tsv](01_infos/all_samples.tsv) and return a file [01_infos/all_demultiplex.csv](01_infos/all_demultiplex.csv) which can be used to process rapidrun data in the next steps of the workflow.

[01_infos/all_demultiplex.csv](01_infos/all_demultiplex.csv) has 14 fields : *demultiplex,projet,marker,run,plaque,sample,barcode5,barcode3,primer5,primer3,min_f,min_r,lenBarcode5,lenBarcode3* and each row is an unique sample which belong to an unique marker and a project.

## 2 Assembly

```
CORES=16
CONFIGFILE=01_infos/config_test.yaml
cd 02_assembly
snakemake --configfile "../"$CONFIGFILE -s Snakefile -j $CORES --use-singularity --singularity-args "--bind /media/superdisk:/media/superdisk" --latency-wait 20
```

Merge paired-end sequences and remove unaligned sequences records.

## 3 Demultiplexing

```
cd 03_demultiplexing
snakemake --configfile "../"$CONFIGFILE -s Snakefile -j $CORES --use-singularity --singularity-args "--bind /media/superdisk:/media/superdisk" --latency-wait 20
```

The tags correspond to short and specific sequences added on the 5’ end of each primer to distinguish the different samples

## 4 Filter samples

```
cd 04_filter_samples
snakemake --configfile "../"$CONFIGFILE -s Snakefile -j $CORES --use-singularity --singularity-args "--bind /media/superdisk:/media/superdisk" --latency-wait 20
```

For each sample, dereplicate sequences, remove sequences with a given length, remove sequences with IUAPC ambiguity, remove PCR clone, remove sequences which are classified as 'internal' by `obiclean`

## 5 Concatenate samples into runs

```
for projet in `ls 04_filter_samples/04_filtered/`;
do 
 for marker in `ls 04_filter_samples/04_filtered/${projet}/`;
 do
  for run in `ls 04_filter_samples/04_filtered/${projet}/${marker}/`;
  do
  echo 04_filter_samples/04_filtered/${projet}/${marker}/${run};
  mkdir -p 05_assignment/01_runs/${projet}/${marker}/
  cat 04_filter_samples/04_filtered/${projet}/${marker}/${run}/*.c.r.l.u.fasta > 05_assignment/01_runs/${projet}/${marker}/${run}.fasta
  done
 done
done
```

sample files are concatenated by run

## 6 Assignment

```
cd 05_assignment
snakemake --configfile "../"$CONFIGFILE -s Snakefile -j $CORES --use-singularity --singularity-args "--bind /media/superdisk:/media/superdisk" --latency-wait 20
```

Assign each sequence to a taxon. Format the output into a csv results in folder [06_final_tables](06_final_tables)