###############################################################################
## Here, we reproduce the bioinformatics workflow used by SPYGEN 
## We improve its performance by adding parallelization and containerazition features.
##
## This workflow generates species environmental presence from raw eDNA data. 
##
## This workflow use the workflow management system SNAKEMAKE.
## 
##
## Author : GUERIN Pierre-Edouard
## Montpellier 2019-2020
## 
###############################################################################
## Usage:
##    CORE=16
##    CONFIGFILE=path/to/my/configfile.yaml
##    bash main.sh $CORES $CONFIGFILE
##
##
###############################################################################
CORES=$1
CONFIGFILE=$2
##
CORES=16
CONFIGFILE="01_infos/config_test.yaml"


###############################################################################
## write demultiplex table
snakemake --configfile $CONFIGFILE -s readwrite_rapidrun_demultiplexing.py
## assemble
cd 02_assembly
snakemake --configfile "../"$CONFIGFILE -s Snakefile -j $CORES --use-singularity --singularity-args "--bind /media/superdisk:/media/superdisk" --latency-wait 20
cd ..
## demultiplex
cd 03_demultiplex
snakemake --configfile "../"$CONFIGFILE -s Snakefile -j $CORES --use-singularity --singularity-args "--bind /media/superdisk:/media/superdisk" --latency-wait 20
cd ..
## filter samples
cd 04_filter_samples
snakemake --configfile "../"$CONFIGFILE -s Snakefile -j $CORES --use-singularity --singularity-args "--bind /media/superdisk:/media/superdisk" --latency-wait 20
cd ..
## concatenate samples into run
for projet in `ls 04_filter_samples/04_filtered/`;
do 
 for marker in `ls 04_filter_samples/04_filtered/${projet}/`;
 do
  for run in `ls 04_filter_samples/04_filtered/${projet}/${marker}/`;
  do
  echo 04_filter_samples/04_filtered/${projet}/${marker}/${run};
  mkdir -p 05_assignment/01_runs/${projet}/${marker}/
  cat 04_filter_samples/04_filtered/${projet}/${marker}/${run}/*.c.r.l.u.fasta > 05_assignment/01_runs/${projet}/${marker}/${run}.fasta
  done
 done
done
## assignment
cd 05_assignment
snakemake --configfile "../"$CONFIGFILE -s Snakefile -j $CORES --use-singularity --singularity-args "--bind /media/superdisk:/media/superdisk" --latency-wait 20
cd ..

############################################################################### 
## rename files
# bash rename.sh 06_assignment
## clean
#snakemake --configfile "../"$CONFIGFILE -s Snakefile --delete-all-output --dry-run
#snakemake --configfile "../"$CONFIGFILE -s Snakefile --delete-all-output --rerun-incomplete
#nohup snakemake --configfile "../"$CONFIGFILE -s Snakefile -j $CORES --use-singularity --singularity-args "--bind /media/superdisk:/media/superdisk" --latency-wait 20 &
#snakemake --configfile "../"$CONFIGFILE -s Snakefile -j $CORES --use-singularity --singularity-args "--bind /media/superdisk:/media/superdisk" --latency-wait 20 --dry-run
